feedbackTextstyle property
Face Capture's SDK offers feedback on how a user should better orient themselves to allow for an effective Face Capture. This is returned as a string that can be fully customized.
Implementation
final TextStyle feedbackTextstyle;