CaptureSessionStatus enum
Values
- idle → const CaptureSessionStatus
-
const CaptureSessionStatus(0) - starting → const CaptureSessionStatus
-
const CaptureSessionStatus(1) - capturing → const CaptureSessionStatus
-
const CaptureSessionStatus(2) - postCaptureProcessing → const CaptureSessionStatus
-
const CaptureSessionStatus(3) - completed → const CaptureSessionStatus
-
const CaptureSessionStatus(4) - aborted → const CaptureSessionStatus
-
const CaptureSessionStatus(5) - stopped → const CaptureSessionStatus
-
const CaptureSessionStatus(6) - timedOut → const CaptureSessionStatus
-
const CaptureSessionStatus(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getByValue(
int value) → CaptureSessionStatus
Constants
-
values
→ const List<
CaptureSessionStatus> - A constant List of the values in this enum, in order of their declaration.