Globals class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- cameraOrientation ↔ String
-
getter/setter pair
- cameraPosition ↔ String
-
getter/setter pair
- cameras ↔ List
-
getter/setter pair
-
captureRegion
↔ Rectangle<
num> ? -
getter/setter pair
- captureTimeout ↔ String
-
getter/setter pair
- faceCaptureLibrary ↔ FaceCapture?
-
getter/setter pair
- faceCaptureState ↔ CaptureState?
-
getter/setter pair
- faceCaptureVersion ↔ String
-
getter/setter pair
- faceCaptureWorkflow ↔ Workflow?
-
getter/setter pair
- livenessServerStatus ↔ bool
-
getter/setter pair
- livenessServerVersion ↔ String
-
getter/setter pair
- livenessUrl ↔ String
-
getter/setter pair
- packageType ↔ String
-
getter/setter pair
- profile ↔ String
-
getter/setter pair
-
profiles
↔ List<
String> -
getter/setter pair
- screenOrientation ↔ CameraOrientation
-
getter/setter pair
- screenRatio ↔ double
-
getter/setter pair
- userName ↔ String
-
getter/setter pair
- workflow ↔ String
-
getter/setter pair
Static Methods
-
initialize(
String profile, String username, double timeout) → Future< InitializeResult>